==> haskell-wai-3.2.4-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai
version:              3.2.4
visibility:           public
id:                   wai-3.2.4-9jkCTz3VUjM6XVKXhFmJSz
key:                  wai-3.2.4-9jkCTz3VUjM6XVKXhFmJSz
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             https://github.com/yesodweb/wai
synopsis:             Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.

    API docs and the README are available at <http://www.stackage.org/package/wai>.

category:             Web
abi:                  c8f694202d32e4cd754576129dd267f8
exposed:              True
exposed-modules:      Network.Wai Network.Wai.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-3.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-3.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-3.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai
hs-libraries:         HSwai-3.2.4-9jkCTz3VUjM6XVKXhFmJSz
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    http-types-0.12.4-B5DxmOwiWvxHN2hLvYjsdc
    network-3.1.4.0-KV3OkCyx0pcI1DdyD3ZbeB text-2.0.2
    vault-0.3.1.5-2DYPbLdvpg42QmkcOZqzQH

haddock-interfaces:   /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html:         /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-3.2.4-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai
version:              3.2.4
visibility:           public
id:                   wai-3.2.4-EhNMiHqwqcPHb2wBYuWApz
key:                  wai-3.2.4-EhNMiHqwqcPHb2wBYuWApz
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             https://github.com/yesodweb/wai
synopsis:             Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.

    API docs and the README are available at <http://www.stackage.org/package/wai>.

category:             Web
abi:                  ff556badc2373c13c134fdb42b3090db
exposed:              True
exposed-modules:      Network.Wai Network.Wai.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-3.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-3.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-3.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai
hs-libraries:         HSwai-3.2.4-EhNMiHqwqcPHb2wBYuWApz
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    http-types-0.12.4-22ca4VB3NcX8GYX2Ium30U
    network-3.1.4.0-9WwAYDZyp2nAB4XV6sI63l text-2.0.2
    vault-0.3.1.5-6YWe0Eer5Lm5jZV58dLEpm

haddock-interfaces:   /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html:         /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
